@@ -87,6 +87,22 @@ fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
     )
 }
 
+#[test_case(MarketType::Spot, "BTC-USDT")]
+#[test_case(MarketType::InverseFuture, "BTC-USD-211231")]
+#[test_case(MarketType::LinearFuture, "BTC-USDT-211231")]
+#[test_case(MarketType::InverseSwap, "BTC-USD-SWAP")]
+#[test_case(MarketType::LinearSwap, "BTC-USDT-SWAP")]
+#[test_case(MarketType::EuropeanOption, "BTC-USD-211231-18000-P")]
+fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
+    gen_test_code!(
+        crawl_l2_topk,
+        EXCHANGE_NAME,
+        market_type,
+        symbol,
+        MessageType::L2TopK
+    )
+}
+
 #[test_case(MarketType::Spot, "BTC-USDT")]
 #[test_case(MarketType::InverseFuture, "BTC-USD-211231")]
 #[test_case(MarketType::LinearFuture, "BTC-USDT-211231")]
